#
# Copyright (C) 2013  Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY expressed or implied, including the implied warranties of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the
# GNU General Public License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
# source code or documentation are not subject to the GNU General Public
# License and may only be used or replicated with the express permission of
# Red Hat, Inc.
#
"""Text mode firmware spoke"""

import json

from pyanaconda.ui.categories.system import SystemCategory
from pyanaconda.ui.tui.spokes import NormalTUISpoke
from pyanaconda.ui.common import FirstbootSpokeMixIn
from pyanaconda.core.i18n import N_, _
from pyanaconda.core.configuration.anaconda import conf
from pyanaconda.core.constants import ANACONDA_ENVIRON
from pyanaconda.core.util import execConsole
from blivet import arch

from simpleline.render.containers import ListColumnContainer
from simpleline.render.screen import InputState
from simpleline.render.widgets import TextWidget


class FirmwareSpoke(FirstbootSpokeMixIn, NormalTUISpoke):
    """
       .. inheritance-diagram:: ShellSpoke
          :parts: 3
    """
    category = SystemCategory

    @staticmethod
    def get_screen_id():
        """Return a unique id of this UI screen."""
        return "firmware-configuration"

    def __init__(self, data, storage, payload):
        super().__init__(data, storage, payload)
        self.title = N_("Firmware")
        self.initialize_start()
        self._container = None
        self._firmware = ""
        self.initialize_done()

    @classmethod
    def should_run(cls, environment, data):
        return FirstbootSpokeMixIn.should_run(environment, data)

    @property
    def completed(self):
        return self._firmware != ""

    @property
    def status(self):
        if self._firmware:
            return self._firmware
        else:
            return _("Firmware is not set.")

    def refresh(self, args=None):
        NormalTUISpoke.refresh(self, args)
        list = json.load(open("/firmwares.json"))
        self._container = ListColumnContainer(3)
        self.window.add(TextWidget(_("Available firmwares")))
        for (k, v) in list.items():
            widget = TextWidget(v)
            self._container.add(widget, self._set_firmware_callback, k)
        self.window.add_with_separator(self._container)

    def _set_firmware_callback(self, firmware):
        self._firmware = firmware
        fo = open("/firmware.txt", "w")
        fo.write(firmware)
        fo.close()
        self.close()

    def input(self, args, key):
        if self._container.process_user_input(key):
            return InputState.PROCESSED
        return super().input(args, key)

    def prompt(self, args=None):
        prompt = NormalTUISpoke.prompt(self, args)
        prompt.set_message(_("Please select firmware to install"))
        return prompt
